searchData={"content_type":"text/markdown","items":[{"doc":"`Enfiladex` is the drop-in `Common Test` wrapper for _ExUnit_. It also exposes functions\nto run some code on a freshly started remote node(s).\n\nAll one needs to evaluate the code on one or more of connected nodes, would be to\ncall a function exported from this module.\n\nKnown config parameters:\n\n- **`transfer_config`** (default: `true`) — whether the configuration of application(s)\n  should be transferred to the started nodes, accepts `boolean() | atom()` where `atom()`\n  is the application name besides already loaded the config is to be transferred for,\n  normally it’s the main application configuration\n- **`start_applications`** (default: `true`) — `boolean() | atom()` specifying whether\n  the application(s) should have been starter on the spawned node(s)\n- **`nodes`** (default: `3`) — for `multi_peer/3`, the number of nodes to start\n\n---\n\nTo use functions from this module with `ExUnit` tests, one needs a named node.\n  Either run `mix test` in a named environment, or use `mix enfiladex.ex_unit` task.\n  Make sure `epmd` (of any service providing distribution) is started in the target environment.\n\nAllowed start options besides ones above: https://www.erlang.org/doc/man/peer#type-start_options\n\nMore `rpc` functions which might be used: https://www.erlang.org/doc/man/rpc","ref":"Enfiladex.html","title":"Enfiladex","type":"module"},{"doc":"Calls the function on all the nodes, visible to this node.\n\nUse `Enfiladex.rpc_block_call/2` to call the function on selected nodes (e. g. on all the connected nodes,)\n  as `rpc_block_call([node() | Node.list(:connected)], {mod, fun, args})`.\n\nSee [node types](https://www.erlang.org/doc/man/erlang.html#nodes-1) for more info.","ref":"Enfiladex.html#block_call_everywhere/3","title":"Enfiladex.block_call_everywhere/3","type":"function"},{"doc":"Calls the function on all the nodes, visible to this node.\n\nUse `Enfiladex.rpc_call/2` to call the function on selected nodes (e. g. on all the connected nodes,)\n  as `rpc_call([node() | Node.list(:connected)], {mod, fun, args})`.\n\nSee [node types](https://www.erlang.org/doc/man/erlang.html#nodes-1) for more info.","ref":"Enfiladex.html#call_everywhere/3","title":"Enfiladex.call_everywhere/3","type":"function"},{"doc":"Executes the function given as first argument on several newly spawned nodes, with options\n  passed as `config` argument.\n\nIt would call `Callback(Result)` for each result on each node, if `callback` was passed, before\n  stopping the peer. The order is not guaranteed.","ref":"Enfiladex.html#multi_peer/3","title":"Enfiladex.multi_peer/3","type":"function"},{"doc":"Executes the function given as first argument on the newly spawned node, with options\n  passed as `config` argument.\n\nIt would call `Callback(Result)` if `callback` passed before stopping the peer.","ref":"Enfiladex.html#peer/3","title":"Enfiladex.peer/3","type":"function"},{"doc":"iex> {_, _, result} = Enfiladex.peer({IO, :inspect, [:ok]})\n    ...> result\n    :ok","ref":"Enfiladex.html#peer/3-examples","title":"Examples - Enfiladex.peer/3","type":"function"},{"doc":"Calls the function passed as `t:mfa/0` on remote nodes passed as the first argument.\n\nUses [`:rpc.block_call/4`](https://www.erlang.org/doc/man/rpc#block_call-4) for non-blocking cross-node call.","ref":"Enfiladex.html#rpc_block_call/2","title":"Enfiladex.rpc_block_call/2","type":"function"},{"doc":"Calls the function passed as `t:mfa/0` on remote nodes passed as the first argument.\n\nUses [`:rpc.call/4`](https://www.erlang.org/doc/man/rpc#call-4) for non-blocking cross-node call.","ref":"Enfiladex.html#rpc_call/2","title":"Enfiladex.rpc_call/2","type":"function"},{"doc":"Starts the requested amount of peers. These peers should be then stopped with `stop_peers/1`.","ref":"Enfiladex.html#start_peers/2","title":"Enfiladex.start_peers/2","type":"function"},{"doc":"Stops the peers previously started with `start_peers/1`.","ref":"Enfiladex.html#stop_peers/1","title":"Enfiladex.stop_peers/1","type":"function"},{"doc":"The callback to be called on the result on the remote node(s)","ref":"Enfiladex.html#t:callback/0","title":"Enfiladex.callback/0","type":"type"},{"doc":"The return value of the callback function executed from remote peer","ref":"Enfiladex.html#t:callback_return_value/0","title":"Enfiladex.callback_return_value/0","type":"type"},{"doc":"The function to be passed for execution on the remote node(s)","ref":"Enfiladex.html#t:callee/0","title":"Enfiladex.callee/0","type":"type"},{"doc":"The return value of the function executed on remote peer","ref":"Enfiladex.html#t:callee_return_value/0","title":"Enfiladex.callee_return_value/0","type":"type"},{"doc":"The peer handler","ref":"Enfiladex.html#t:peer/0","title":"Enfiladex.peer/0","type":"type"},{"doc":"The result of starting a peer as returned by erlang","ref":"Enfiladex.html#t:started_peer/0","title":"Enfiladex.started_peer/0","type":"type"},{"doc":"`use Enfiladex` is the drop-in `Common Test` wrapper for _ExUnit_.\n\n\n> ### `use Enfiladex.Suite` {: .info}\n>\n> When you `use Enfiladex.Suite`, the tests in the case become available to use with `common_test`:\n>\n> - calls to `setup/2` and `setup_all/2` are also injected as `init_per_***/2` and `end_per_***/2`\n> - `groups/0` and `all/0` are injectd based on your `describe/2` and `test/2` calls\n\n\n\n**`@enfiladex_group_strategy`** attribute can be set before each `describe/2` call to one of the following values:\n\n- **`[]`** (empty list / no option)\n  - The test cases in the group are run one after the other. If a test fails, the others after it in the list are run.\n- **`:shuffle`**\n  - Runs the test in a random order. The random seed (the initialization value) used for the sequence will be printed in the HTML logs, of the form {A,B,C}. If a particular sequence of tests fails and you want to reproduce it, use that seed in the HTML logs and change the shuffle option to instead be {shuffle, {A,B,C}}. That way you can reproduce random runs in their precise order if you ever need to.\n- **`:parallel`**\n  - The tests are run in different processes. Be careful because if you forget to export the init_per_group and end_per_group functions, Common Test will silently ignore this option.\n- **`:sequence`**\n  - Doesn't necessarily mean that the tests are run in order, but rather that if a test fails in the group's list, then all the other subsequent tests are skipped. This option can be combined with shuffle if you want any random test failing to stop the ones after.\n- **`{:repeat, times}`**\n  - Repeats the group Times times. You could thus run all test cases in the group in parallel 9 times in a row by using the group properties [parallel, {repeat, 9}]. Times can also have the value forever, although 'forever' is a bit of a lie as it can't defeat concepts such as hardware failure or heat death of the Universe (ahem).\n- **`{:repeat_until_any_fail, n}`**\n  - Runs all the tests until one of them fails or they have been run N times. N can also be forever.\n- **`{:repeat_until_all_fail, n}`**\n  - Same as above, but the tests may run until all cases fail.\n- **`{:repeat_until_any_succeed, n}`**\n  - Same as before, except the tests may run until at least one case succeeds.\n- **`{:repeat_until_all_succeed, n}`**\n  - I think you can guess this one by yourself now, but just in case, it's the same as before except that the test cases may run until they all succeed.\n\n[Common Test for Uncommon Tests](https://learnyousomeerlang.com/common-test-for-uncommon-tests)","ref":"Enfiladex.Suite.html","title":"Enfiladex.Suite","type":"module"},{"doc":"","ref":"Enfiladex.Suite.html#doctest/2","title":"Enfiladex.Suite.doctest/2","type":"macro"},{"doc":"Mix task to run `commot_test` with `ExUnit` test files.\n\nAccepted arguments:\n\n- **`--test-dir`** (_default:_ `[\"test\"]`) — accumulated list of dirs to run `enfiladex` task in\n- **`--ct-logs-dir`** (_default:_ `[\"ct_logs\"]`) — the directory where to pul `ct_logs` outcome to\n\nFull [list of options](https://www.erlang.org/doc/man/ct#run_test-1):\n\n* **✓** `{dir, TestDirs}` — as `--test-dir`\n* **✓** `{suite, Suites}` — as suite per test module with `use Enfiladex.Suite`\n* **✓** `{group, Groups}` — as gained from `describe` blocks per suite\n* **✗** `{testcase, Cases}`\n* **✗** `{spec, TestSpecs}`\n* **✗** `{join_specs, boolean()}`\n* **✗** `{label, Label}`\n* **✗** `{config, CfgFiles}`\n* **✗** `{userconfig, UserConfig}`\n* **✗** `{allow_user_terms, boolean()}`\n* **✓** `{logdir, LogDir}` — as `--log-dir`\n* **✗** `{silent_connections, Conns}`\n* **✗** `{stylesheet, CSSFile}`\n* **✗** `{cover, CoverSpecFile}` — requires `.erl` files, TODO\n* **✗** `{cover_stop, boolean()}`\n* **✗** `{step, StepOpts}`\n* **✗** `{event_handler, EventHandlers}`\n* **✓** `{include, InclDirs}` — as `--test-dir`\n* **✓** `{auto_compile, boolean()}` — as `false` because `ct` needs `beam` files\n* **✓** `{abort_if_missing_suites, boolean()}` — as hardcoded `true`\n* **✗** `{create_priv_dir, CreatePrivDir}`\n* **✗** `{multiply_timetraps, M}`\n* **✗** `{scale_timetraps, boolean()}`\n* **✗** `{repeat, N}`\n* **✗** `{duration, DurTime}`\n* **✗** `{until, StopTime}`\n* **✗** `{force_stop, ForceStop}`\n* **✗** `{decrypt, DecryptKeyOrFile}`\n* **✗** `{refresh_logs, LogDir}`\n* **✗** `{logopts, LogOpts}`\n* **✓** `{verbosity, VLevels}` — as hardcoded `100`\n* **✗** `{basic_html, boolean()}`\n* **✗** `{esc_chars, boolean()}`\n* **✗** `{keep_logs, KeepSpec}`\n* **✓** `{ct_hooks, CTHs}` — as provided by `Enfiladex.Hooks`\n* **✗** `{enable_builtin_hooks, boolean()}`\n* **✗** `{release_shell, boolean()}`","ref":"Mix.Tasks.Enfiladex.html","title":"mix enfiladex","type":"task"},{"doc":"","ref":"Mix.Tasks.Enfiladex.html#run/1","title":"Mix.Tasks.Enfiladex.run/1","type":"function"},{"doc":"Mix task to run normal `ExUnit` tests using `Enfiladex` goodness.\n\nPlease set the environment for it in your `mix.exs` file as\n\n```elixir\n  def cli do\n    [\n      preferred_envs: [\n        \"enfiladex\": \"test\",\n        \"enfiladex.ex_unit\": \"test\"\n      ]\n    ]\n  end\n\n  # or inside `project` callback\n\n  preferred_cli_env: [\"enfiladex\": :test, \"enfiladex.ex_unit\": :test],\n\n```","ref":"Mix.Tasks.Enfiladex.ExUnit.html","title":"mix enfiladex.ex_unit","type":"task"},{"doc":"","ref":"Mix.Tasks.Enfiladex.ExUnit.html#run/1","title":"Mix.Tasks.Enfiladex.ExUnit.run/1","type":"function"},{"doc":"Exception raised to indicate the misplaced module attribute.","ref":"Enfiladex.ModuleAttributeError.html","title":"Enfiladex.ModuleAttributeError","type":"exception"},{"doc":"","ref":"Enfiladex.ModuleAttributeError.html#t:t/0","title":"Enfiladex.ModuleAttributeError.t/0","type":"type"},{"doc":"# Enfiladex\n\n**Wrapper for executing `ExUnit` as `common_test` **","ref":"readme.html","title":"Enfiladex","type":"extras"},{"doc":"```elixir\ndef deps do\n  [\n    {:enfiladex, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Enfiladex","type":"extras"},{"doc":"Add `use Enfiladex` to your test to convert it to common test suite.","ref":"readme.html#usage","title":"Usage - Enfiladex","type":"extras"},{"doc":"- `on_exit/2` callbacks with captures makes test to fail compiling with `use Enfiladex` (`Code.with_diagnostics/2` issue),\n- `Enfiladex.{peer/3, multi_peer_/3}` fail from tests with an anonymous function,\n- ~~`MIX_ENV=test iex --sname am -S mix enfiladex` (named node) to execute common test,~~\n- ~~compiled `beam` files are not yet removed.~~\n\n[Documentation](https://hexdocs.pm/enfiladex).","ref":"readme.html#known-issues","title":"Known issues - Enfiladex","type":"extras"},{"doc":"- **`0.3.0`** — `Enfiladex.rpc_[block_]call/2`, `Enfiladex.[block_]call_everywhere/3`\n- **`0.2.1`** — doctests\n- **`0.2.0`** — `start_peers/1`, `stop_peers/1`, self-tested, cleaner interface","ref":"readme.html#changelog","title":"Changelog - Enfiladex","type":"extras"}]}